# yaqc-cmds

[![PyPI](https://img.shields.io/pypi/v/yaqc-cmds)](https://pypi.org/project/yaqc-cmds)
[![Conda](https://img.shields.io/conda/vn/conda-forge/yaqc-cmds)](https://anaconda.org/conda-forge/yaqc-cmds)
[![yaq](https://img.shields.io/badge/framework-yaq-orange)](https://yaq.fyi/)
[![black](https://img.shields.io/badge/code--style-black-black)](https://black.readthedocs.io/)

A qt-based graphical client for [yaq](https://yaq.fyi/) with a focus on controlling hardware and collecting data in multidimensional spectroscopy experiments.

Documentation at [yaqc-cmds.wright.tools](https://yaqc-cmds.wright.tools).

This project is archived using [Zenodo](https://zenodo.org/record/1198910).
Please use DOI: 10.5281/zenodo.1198910 to cite yaqc-cmds.
